==> kubernetes-model-certificates-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestListBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateSigningRequestListBuilder extends CertificateSigningRequestListFluentImpl<CertificateSigningRequestListBuilder> implements VisitableBuilder<CertificateSigningRequestList,CertificateSigningRequestListBuilder>{
  public CertificateSigningRequestListBuilder() {
    this(false);
  }
  public CertificateSigningRequestListBuilder(Boolean validationEnabled) {
    this(new CertificateSigningRequestList(), validationEnabled);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateSigningRequestList(), validationEnabled);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,CertificateSigningRequestList instance) {
    this(fluent, instance, false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,CertificateSigningRequestList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestList instance) {
    this(instance,false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateSigningRequestListFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateSigningRequestList build() {
    CertificateSigningRequestList buildable = new CertificateSigningRequestList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-certificates-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestListBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateSigningRequestListBuilder extends CertificateSigningRequestListFluent<CertificateSigningRequestListBuilder> implements VisitableBuilder<CertificateSigningRequestList,CertificateSigningRequestListBuilder>{
  public CertificateSigningRequestListBuilder() {
    this(false);
  }
  public CertificateSigningRequestListBuilder(Boolean validationEnabled) {
    this(new CertificateSigningRequestList(), validationEnabled);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateSigningRequestList(), validationEnabled);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,CertificateSigningRequestList instance) {
    this(fluent, instance, false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestListFluent<?> fluent,CertificateSigningRequestList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CertificateSigningRequestList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestList instance) {
    this(instance,false);
  }
  public CertificateSigningRequestListBuilder(CertificateSigningRequestList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CertificateSigningRequestList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CertificateSigningRequestListFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateSigningRequestList build() {
    CertificateSigningRequestList buildable = new CertificateSigningRequestList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
